pypi-check
==========

    Check for module name availability in PyPI.

Install
-------

::

    $ pip install pypi-check


Usage
-----

::

    $ pypi-check <module-name>


Contribute
==========

If you want to add features, improve them, or report issues, feel free
to send a pull request.

License
=======

MIT © `Harsha Srinivas`_

.. _Harsha Srinivas: https://harshasrinivas.me
